@@ -7,9 +7,10 @@ Custom input handlers for Parameters
 from __future__ import annotations
 
 import typing as _t
-from enum import Enum as _Enum
+from enum import EnumMeta as _EnumMeta
+from re import Pattern as _Pattern
 
-from ..exceptions import ParameterDefinitionError as _ParameterDefinitionError
+from ..exceptions import ParameterDefinitionError as _ParamDefinitionError
 from .base import InputType
 from .choices import ChoiceMap, Choices, EnumChoices
 from .exceptions import InputValidationError, InvalidChoiceError
@@ -33,36 +34,29 @@ __all__ = [
 ]
 # fmt: on
 
-_INVALID_CHOICES_TYPES = (_t.Pattern, InputType)
-_INVALID_TYPES_WITH_CHOICES = (Range, range, Regex, _t.Pattern, Glob)
+_INVALID_CHOICES_TYPES = (_Pattern, InputType)
+_INVALID_TYPES_WITH_CHOICES = (Range, range, Regex, _Pattern, Glob)
 
 
-def normalize_input_type(type_func: InputTypeFunc, param_choices: ChoicesType) -> _t.Optional[TypeFunc]:
+def normalize_input_type(type_func: InputTypeFunc, param_choices: ChoicesType) -> TypeFunc | None:
     if choices_provided := param_choices is not None:
         if not param_choices:
-            raise _ParameterDefinitionError(
-                f'Invalid choices={param_choices!r} - when specified, choices cannot be empty'
-            )
+            raise _ParamDefinitionError(f'Invalid choices={param_choices!r} - when specified, choices cannot be empty')
         elif isinstance(param_choices, range):
             return Range(param_choices, type_func)
         elif isinstance(param_choices, _INVALID_CHOICES_TYPES):
-            raise _ParameterDefinitionError(f'Invalid choices={param_choices!r} - use type={param_choices!r} instead')
+            raise _ParamDefinitionError(f'Invalid choices={param_choices!r} - use type={param_choices!r} instead')
         elif isinstance(type_func, _INVALID_TYPES_WITH_CHOICES):
-            raise _ParameterDefinitionError(f'Cannot combine type={type_func!r} with choices={param_choices!r}')
+            raise _ParamDefinitionError(f'Cannot combine type={type_func!r} with choices={param_choices!r}')
 
-    if type_func is None:
-        return Choices(param_choices) if choices_provided else type_func
-    elif isinstance(type_func, range):
-        return Range(type_func)
-    elif isinstance(type_func, _t.Pattern):
-        return Regex(type_func)
-
-    try:
-        is_enum = issubclass(type_func, _Enum)
-    except TypeError:
-        pass
-    else:
-        if is_enum:
+    match type_func:
+        case None:
+            return Choices(param_choices) if choices_provided else type_func
+        case range():
+            return Range(type_func)
+        case _Pattern():
+            return Regex(type_func)
+        case _EnumMeta():
             enum_choices = EnumChoices(type_func)
             if choices_provided:
                 return Choices(param_choices, enum_choices)
