@@ -8,7 +8,7 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Collection, Iterator, Mapping, Optional, Set, Type, TypeVar
+from typing import TYPE_CHECKING, Any, Collection, Iterator, Mapping, Type, TypeVar
 
 from ..typing import T, TypeFunc
 from .base import InputType
@@ -25,7 +25,7 @@ EnumT = TypeVar('EnumT', bound=Enum)
 class _ChoicesBase(InputType[T], ABC):
     __slots__ = ('choices', 'type', 'case_sensitive')
     choices: Collection[T]
-    type: Optional[TypeFunc]
+    type: TypeFunc | None
     case_sensitive: bool
 
     def __contains__(self, value: str) -> bool:
@@ -36,7 +36,12 @@ class _ChoicesBase(InputType[T], ABC):
         return True
 
     def _type_str(self) -> str:
-        return f'type={self.type.__name__}, ' if self.type is not None else ''
+        if self.type is not None:
+            try:
+                return f'type={self.type.__name__}, '
+            except AttributeError:  # type is not a class
+                pass
+        return ''
 
     def __repr__(self) -> str:
         cls_name = self.__class__.__name__
@@ -56,7 +61,7 @@ class _ChoicesBase(InputType[T], ABC):
 
     def _iter_normalized(self, value: Any, choices: Collection = None) -> Iterator[T]:
         yield value
-        if not self.case_sensitive and (choices is None or isinstance(choices, (Set, Mapping))):
+        if not self.case_sensitive and (choices is None or isinstance(choices, (set, Mapping))):
             yield value.lower()
             yield value.upper()
 
@@ -100,7 +105,10 @@ class Choices(_ChoicesBase[T]):
         self.case_sensitive = case_sensitive
 
     def _choices_repr(self, delim: str = ',') -> str:
-        return delim.join(map(repr, sorted(self.choices)))
+        try:
+            return delim.join(map(repr, sorted(self.choices)))
+        except TypeError:  # The choice values are not sortable
+            return delim.join(sorted(map(repr, self.choices)))
 
     def __call__(self, value: str) -> T:
         choices = self.choices
